
Privacy Policy
===============================================================================

This document describes the SkyLines privacy policy for services formally
operated and provided by the current project maintainer ([Tobias Bieniek]). It
describes what personal information we may be gathering from you, who can see
this information, and what options you have for controlling this.

[Tobias Bieniek]: mailto:tobias.bieniek@gmail.com

For the protection of the SkyLines service and other users, if you do not agree
with this Privacy Policy, you may not use the service.


Community development
-------------------------------------------------------------------------------

Development of the software behind SkyLines is a community effort, with many
developers involved and work taking place on many separate components.
Generally a good level of care is being taken to ensure that private
information of users of the project will not fall into the wrong hands. This
has come about as a series of independent decisions within the design of the
various components. The following descriptions are a de facto accumulation of
this into a 'privacy policy' describing how we work with the data.

You should always view SkyLines systems and software with a questioning mind,
and feel free to raise any concerns you have about matters of privacy by
contacting us via [email][Tobias Bieniek].


Types of Information We Receive From You, How We Get It, & How We Use It
-------------------------------------------------------------------------------

### Your Public Contributions

> Whatever you upload on SkyLines can be seen and used by everyone.

SkyLines was primarily created to help you share your flights with the world,
and we share your data because you have asked us to do so.

When you upload a flight or use our live tracking feature, you are creating a
permanent, public record. We may use your public information, either aggregated
with the public informations of others or individually, to create new features
or data-related products for you or to learn more about how SkyLines is used.

Unless this Policy says otherwise, you should assume that information that you
actively provide to SkyLines, including personal information, is publicly
visible and can be found by search engines. Like most things on the Internet,
anything you share may be copied and redistributed throughout the Internet by
other people. Please do not contribute any information that you are
uncomfortable making permanently public, like revealing your real name or
aircraft information in your flight details.

You should be aware that specific data made public by you or aggregated data
that is made public by us can be used by anyone for analysis and to infer
information about users.


### Account Information & Registration

> You do not need to create an account to use SkyLines.
>
> If you do create an account, you need to give us your email address.
>
> If you do not create an account, you are limited to viewing the flights of
> others.

Want to create an account? Great! Don't want to create an account? No problem!

You are not required to create an account to view flights of other pilots on
SkyLines. However, if you want to upload your own flights or use the live 
tracking feature you will have to create an account.

If you want to create a standard account, we require only your name, an email
address and a password. Your name will be publicly visible, so please be careful
about using your real name if you don't want to share it. Your password is only
used to verify that the account is yours. Your IP address is also automatically
submitted to us, and we record it temporarily to help prevent abuse. No other
personal information is required: no date of birth, no credit card information.

To gain a better understanding of the demographics of our users, to localize
our services, and to learn how we can improve our services, we may ask you for
more demographic information, such as gender or age, about yourself. We will
tell you if such information is intended to be public or private, so that you
can make an informed decision about whether you want to provide us with that
information. Providing such information is always completely optional. If you
don't want to, you don't have to—it's as simple as that.


### Information Related to Your Use of SkyLines

> We may use common technologies to collect information about how you use
> SkyLines.
>
> We use this information to enhance your user experience and to develop new
> features.

We want to make SkyLines better for you by learning more about how you use it.
Examples of this might include how often you visit SkyLines, what you like,
what you find helpful, how you get to the SkyLines Site, and whether you would
use a helpful feature more if we explained it differently. We also want this
Policy and our practices to reflect our community's values. For this reason, we
keep information related to your use of SkyLines confidential, except as
provided in this Policy.


### Information We Receive Automatically

> Like other websites, we receive some information about you automatically when
> you visit SkyLines. This information helps us administer the service and
> enhance your user experience.

Because of how browsers work and similar to other major websites, we receive
some information automatically when you visit SkyLines. This information
includes the type of device you are using, the type and version of your
browser, your browser's language preference, the type and version of your
device's operating system, in some cases the name of your internet service
provider or mobile carrier, the website that referred you to SkyLines, which
pages you request and visit, and the date and time of each request you make to
the SkyLines server.

Put simply, we use this information to enhance your experience with SkyLines.
For example, we use this information to administer the sites, provide greater
security, and fight vandalism; optimize mobile applications, customize content
and set language preferences, test features to see what works, and improve
performance; understand how users interact with SkyLines, track and study use
of various features, and analyze trends.


### Information We Collect

> We use a variety of commonly-used technologies, like cookies, to understand
> how you use SkyLines, make our services safer and easier to use, and to help
> create a better and more personalized experience for you.

We actively collect some types of information with a variety of commonly-used
technologies. These generally include JavaScript, and a variety of "locally
stored data" technologies, such as cookies and local storage. We realize that
some of these technologies do not have the best reputation in town and can be
used for less-than-noble purposes. So we want to be as clear as we can about
why we use these methods and the type of information we collect with them.

Depending on which technology we use, locally stored data can be anything from
text, pictures, and whole flights to personal information (like your IP
address) and information about your use of SkyLines (like your username or the
time of your visit).

We use this information to make your experience with the SkyLines service safer
and better, to gain a greater understanding of user preferences and their
interaction with the SkyLines service, and to generally improve our services.
We will never use third-party cookies, unless we get your permission to do so.
If you ever come across a third-party data collection tool that has not been
authorized by you (such as one that may have been mistakenly placed by another
user or administrator), please report it to us via [email][Tobias Bieniek].

Locally stored data, and JavaScript help us do things like:

- Provide you with a personalized experience, such as using cookies to know
  your language preference, to remember the user preferences you set so we can
  provide you with the customized look and feel that you want.

- Deliver more relevant content to you faster. For example, we may use local
  storage to store your most recently viewed flights directly on your device,
  so they can be retrieved quickly. Also, we may use cookies to learn about the
  topics searched so that we can optimize the search results we deliver to you.

- Make the SkyLines more convenient to use, such as by using cookies to
  maintain your session when you log in or to remember your email address in
  the login field.

We believe this data collection helps improve your user experience, but you may
remove or disable some or all locally stored data through your browser settings,
depending on your browser. While locally stored data may not be necessary to
use our sites, some features may not function properly if you disable locally
stored data.

While the examples above concerning information about you collected through the
use of data collection tools are kept confidential in accordance with this
Policy, please note that some information about the actions taken by your
account is made publicly available through public logs alongside actions
taken by other users. For example, a public log may include the date your
account was created on the SkyLines service along with the dates that other
accounts were created.


### Emails

> We will keep your email address confidential, except as provided in this
> Policy.
>
> We may occasionally send you emails about important information.
>
> You may choose to opt out of certain kinds of notifications.

You will have to provide an email address at the time of registration or in
later interactions with the SkyLines service. Your email address is kept
confidential, except as provided in this Policy. We do not sell, rent, or use
your email address to advertise third-party products or services to you.

We use your email address to let you know about things that are happening with 
the SkyLines service, such as telling you important information about your
account, letting you know if something is changing about SkyLines or its
policies, and alerting you about any notifications you have set up. Please note
that if you email us, we may keep your message, email address, and any other
information you provide us, so that we can process and respond to your request.

You can choose to limit some of these kinds of notifications, like those
alerting you if a followed user uploads a new flight. Others, such as those
containing critical information that all users need to know to participate
successfully in the SkyLines community, you may not be able to opt out of.

We will never ask for your password by email (but may send you a temporary
password via email if you have requested a password reset). If you ever receive
such an email, please let us know by sending it via [email][Tobias Bieniek], so
we can investigate the source of the email.


### Location Information

> When you upload your flight logs on SkyLines or provide us with your
> location history through the live tracking feature that information will be
> public.

The main reason for SkyLines is helping you share your flights with the public.
Thus if you use these features, be it uploading of flights as IGC files or
using the live tracking feature, you are sharing your location history with
the public. If you do not want to share your location history you must not use
these features.


### IP Addresses

> When you visit any SkyLines page, we automatically receive the IP address of
> the device you are using to access the Internet, which can be used to infer
> your geographical location.

Finally, when you visit any SkyLines page, we automatically receive the IP
address of the device (or your proxy server) you are using to access the
Internet, which could be used to infer your geographical location. We keep IP
addresses confidential, except as provided in this Policy. We use IP addresses
for research and analytics; to better personalize content, notices, and
settings for you; to fight spam, identity theft, malware, and other kinds of
abuse; and to provide better mobile and other applications.


When May We Share Your Information?
-------------------------------------------------------------------------------

### With Your Permission

> We may share your information when you give us specific permission to do so.

We may share your information for a particular purpose, if you agree.


### For Legal Reasons

> We will disclose your information in response to an official legal process
> only if we believe it to be legally valid. We will notify you of such
> requests when possible.

We may access, preserve, or disclose your personal information if we reasonably
believe it necessary to satisfy a valid and legally enforceable warrant,
subpoena, court order, law or regulation, or other judicial or administrative
order. However, if we believe that a particular request for disclosure of a
user's information is legally invalid or an abuse of the legal system and the
affected user does not intend to oppose the disclosure themselves, we will try
our best to fight it. We are committed to notifying you via email, when
possible, before we disclose your personal information in response to a legal
demand. However, we may only provide notice if we are not legally restrained
from contacting you, there is no credible threat to life or limb that is
created or increased by disclosing the request, and you have provided us with
an email address.

Nothing in this Privacy Policy is intended to limit any legal objections or
defenses you may have to a third party's request (whether it be civil,
criminal, or governmental) to disclose your information. We recommend seeking
the advice of legal counsel immediately if such a request is made involving
you.


### To Protect You, Ourselves & Others

> We, or users with certain administrative rights, may disclose information
> that is reasonably necessary to:
> 
> - enforce or investigate potential violations of our policies;
> - protect our organization, infrastructure, contributors, or the public; or
> - prevent imminent or serious bodily harm or death to a person.

We, or particular users with certain administrative rights as described below,
may need to share your personal information if it is reasonably believed to be
necessary to enforce or investigate potential violations of our policies. We
may also need to access and share information to investigate and defend
ourselves against legal threats or actions.

We hope that this never comes up, but we may disclose your personal information
if we believe that it's reasonably necessary to prevent imminent and serious
bodily harm or death to a person, or to protect our organization,
infrastructure, contributors, users, or the public. We may also disclose your
personal information if we reasonably believe it necessary to detect, prevent,
or otherwise assess and address potential spam, malware, fraud, abuse, unlawful
activity, and security or technical concerns.


### To Our Service Providers

> We may disclose personal information to our third-party service providers or
> contractors to help run or improve the SkyLines service and provide services
> in support of our mission.

As hard as we may try, we can't do it all. So sometimes we use third-party
service providers who help run or improve Skylines for you and other users.
We may give access to your personal information to these providers as needed
to perform their services for us or to use their tools and services. We put
requirements, such as confidentiality agreements, in place to help ensure that
these service providers treat your information consistently with, and no less
protective of your privacy than, the principles of this Policy.


### To Understand & Experiment

> We may give volunteer developers and researchers access to systems that
> contain your information to allow them to protect, develop, and contribute
> to the SkyLines service.
>
> We may also share non-personal or aggregated information with third parties
> interested in studying SkyLines.
>
> When we share information with third parties for these purposes, we put
> reasonable technical and contractual protections in place to protect your
> information consistent with this Policy.

The open-source software that powers the SkyLines service depends on the
contributions of volunteer software developers, who spend time writing and
testing code to help it improve and evolve with our users' needs. To facilitate
their work, we may give some developers limited access to systems that contain
your personal information, but only as reasonably necessary for them to develop
and contribute to the SkyLines service.

Similarly, we may share non-personal or aggregated information with
researchers, scholars, academics, and other interested third parties who wish
to study the SkyLines service. Sharing this information helps them understand
usage, viewing, and demographics statistics and patterns. They then can share
their findings with us and our users so that we can all better understand and
improve SkyLines.

When we give access to personal information to third-party developers or
researchers, we put requirements, such as reasonable technical and contractual
protections, in place to help ensure that these service providers treat your
information consistently with the principles of this Policy and in accordance
with our instructions. If these developers or researchers later publish their
work or findings, we ask that they not disclose your personal information.
Please note that, despite the obligations we impose on developers and
researchers, we cannot guarantee that they will abide by our agreement, nor do
we guarantee that we will regularly screen or audit their projects.


### Because You Made It Public

> Information that you post is public and can been seen and used by everyone.

Any information you post publicly on SkyLines is just that – public. For
example, if you put your email address in a comment, that is public, and not
protected by this Policy. Please think carefully about your desired level of
anonymity before you disclose personal information on your user page or
elsewhere.


Protection
-------------------------------------------------------------------------------

### How Do We Protect Your Data?

> We use a variety of physical and technical measures, policies, and procedures
> to help protect your information from unauthorized access, use, or disclosure.

We strive to protect your information from unauthorized access, use, or
disclosure. We use a variety of physical and technical measures, policies,
and procedures designed to protect our systems and your personal information.
Unfortunately, there's no such thing as completely secure data transmission or
storage, so we can't guarantee that our security will not be breached (by
technical measures or through violation of our policies and procedures).


### How Long Do We Keep Your Data?

> We only keep your personal information as long as necessary to maintain,
> understand, and improve SkyLines or to comply with national law.

Once we receive personal information from you, we keep it for the shortest
possible time that is consistent with the maintenance, understanding, and
improvement of the SkyLines service, and our obligations under applicable
national law. Non-personal information may be retained indefinitely.

---

The text of this Privacy Policy is available under the
[Creative Commons Attribution-ShareAlike License][CC-BY-SA] and was adapted from
the [Wikipedia Privacy Policy].

[CC-BY-SA]: https://creativecommons.org/licenses/by-sa/3.0/
[Wikipedia Privacy Policy]: https://wikimediafoundation.org/wiki/Privacy_policy
